@@ -24,13 +24,14 @@
 
 #include <QTextDocumentFragment>
 #include <QtWaylandClient/private/qwaylandwindow_p.h>
+#include <LayerShellQt/Window>
+
 
 #define FORMAT24H "HH:mm:ss"
 
-ShellUtil::ShellUtil(QObject *parent)
-    : QObject{parent}
-    , m_localeConfig{KSharedConfig::openConfig(QStringLiteral("kdeglobals"), KConfig::SimpleConfig)}
-{
+
+ShellUtil::ShellUtil(QObject *parent) : QObject{parent}, m_localeConfig {
+    KSharedConfig::openConfig(QStringLiteral("kdeglobals"), KConfig::SimpleConfig) } {
 }
 
 void ShellUtil::stackItemBefore(QQuickItem *item1, QQuickItem *item2)
@@ -105,14 +106,20 @@ void ShellUtil::setInputTransparent(QQuickWindow *window, bool transparent) {
     }
 }
 
-void ShellUtil::setInputRegion(QWindow *window, const QRect &region)
-{
+void ShellUtil::setWindowLayer(QQuickWindow *window, LayerShellQt::Window::Layer layer) {
+    if (window) {
+        auto layerShellWindow = LayerShellQt::Window::get(window);
+        layerShellWindow->setLayer(layer);
+    }
+}
+
+void ShellUtil::setInputRegion(QWindow *window, const QRect &region) {
     auto waylandWindow = dynamic_cast<QtWaylandClient::QWaylandWindow *>(window->handle());
     if (!waylandWindow) {
         qWarning() << "Failed to retrieve Wayland window handle.";
         return;
     }
-
+    
     auto waylandDisplay = dynamic_cast<QtWaylandClient::QWaylandDisplay *>(waylandWindow->display());
     if (!waylandDisplay) {
         qWarning() << "Failed to retrieve Wayland display.";
@@ -144,7 +151,6 @@ void ShellUtil::setInputRegion(QWindow *window, const QRect &region)
     wl_surface_commit(surface);
 }
 
-QString ShellUtil::toPlainText(QString htmlString)
-{
+QString ShellUtil::toPlainText(QString htmlString) {
     return QTextDocumentFragment::fromHtml(htmlString).toPlainText();
 }
