@@ -8,22 +8,28 @@
 ShellDBusClient::ShellDBusClient(QObject *parent)
     : QObject{parent}
     , m_interface{new OrgKdePlasmashellInterface{QStringLiteral("org.kde.plasmashell"), QStringLiteral("/Mobile"), QDBusConnection::sessionBus(), this}}
-    , m_watcher{new QDBusServiceWatcher(QStringLiteral("org.kde.plasmashell"), QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForOwnerChange, this)}
     , m_connected{false}
 {
-    if (m_interface->isValid()) {
-        connectSignals();
-    }
-
-    connect(m_watcher, &QDBusServiceWatcher::serviceRegistered, this, [this]() -> void {
+    // Check if the service is already running
+    if (QDBusConnection::sessionBus().interface()->isServiceRegistered(QStringLiteral("org.kde.plasmashell"))) {
         m_connected = true;
         if (m_interface->isValid()) {
             connectSignals();
         }
-    });
+    }
 
-    connect(m_watcher, &QDBusServiceWatcher::serviceUnregistered, this, [this]() -> void {
-        m_connected = false;
+    connect(QDBusConnection::sessionBus().interface(), &QDBusConnectionInterface::serviceOwnerChanged, this, [this](const QString &service, const QString &oldOwner, const QString &newOwner) {
+        Q_UNUSED(oldOwner);
+        if (service == QStringLiteral("org.kde.plasmashell")) {
+            if (!newOwner.isEmpty() && !m_connected) {
+                m_connected = true;
+                if (m_interface->isValid()) {
+                    connectSignals();
+                }
+            } else if (newOwner.isEmpty() && m_connected) {
+                m_connected = false;
+            }
+        }
     });
 }
 
@@ -31,6 +37,8 @@ void ShellDBusClient::connectSignals()
 {
     connect(m_interface, &OrgKdePlasmashellInterface::panelStateChanged, this, &ShellDBusClient::updatePanelState);
     connect(m_interface, &OrgKdePlasmashellInterface::isActionDrawerOpenChanged, this, &ShellDBusClient::updateIsActionDrawerOpen);
+    connect(m_interface, &OrgKdePlasmashellInterface::isVolumeOSDOpenChanged, this, &ShellDBusClient::updateIsVolumeOSDOpen);
+    connect(m_interface, &OrgKdePlasmashellInterface::isNotificationPopupDrawerOpenChanged, this, &ShellDBusClient::updateIsNotificationPopupDrawerOpen);
     connect(m_interface, &OrgKdePlasmashellInterface::doNotDisturbChanged, this, &ShellDBusClient::updateDoNotDisturb);
     connect(m_interface, &OrgKdePlasmashellInterface::isTaskSwitcherVisibleChanged, this, &ShellDBusClient::updateIsTaskSwitcherVisible);
     connect(m_interface, &OrgKdePlasmashellInterface::openActionDrawerRequested, this, &ShellDBusClient::openActionDrawerRequested);
@@ -43,7 +51,6 @@ void ShellDBusClient::connectSignals()
     connect(m_interface, &OrgKdePlasmashellInterface::resetHomeScreenPositionRequested, this, &ShellDBusClient::resetHomeScreenPositionRequested);
     connect(m_interface, &OrgKdePlasmashellInterface::showVolumeOSDRequested, this, &ShellDBusClient::showVolumeOSDRequested);
 
-    updateIsActionDrawerOpen();
     updateDoNotDisturb();
     updateIsTaskSwitcherVisible();
 }
@@ -78,6 +85,26 @@ void ShellDBusClient::setIsActionDrawerOpen(bool value)
     m_interface->setIsActionDrawerOpen(value);
 }
 
+bool ShellDBusClient::isVolumeOSDOpen() const
+{
+    return m_isVolumeOSDOpen;
+}
+
+void ShellDBusClient::setIsVolumeOSDOpen(bool value)
+{
+    m_interface->setIsVolumeOSDOpen(value);
+}
+
+bool ShellDBusClient::isNotificationPopupDrawerOpen() const
+{
+    return m_isNotificationPopupDrawerOpen;
+}
+
+void ShellDBusClient::setIsNotificationPopupDrawerOpen(bool value)
+{
+    m_interface->setIsNotificationPopupDrawerOpen(value);
+}
+
 void ShellDBusClient::openActionDrawer()
 {
     m_interface->openActionDrawer();
@@ -160,6 +187,30 @@ void ShellDBusClient::updateIsActionDrawerOpen()
     });
 }
 
+void ShellDBusClient::updateIsVolumeOSDOpen()
+{
+    auto reply = m_interface->isVolumeOSDOpen();
+    auto watcher = new QDBusPendingCallWatcher(reply, this);
+
+    QObject::connect(watcher, &QDBusPendingCallWatcher::finished, this, [this](auto watcher) {
+        QDBusPendingReply<bool> reply = *watcher;
+        m_isVolumeOSDOpen = reply.argumentAt<0>();
+        Q_EMIT isVolumeOSDOpenChanged();
+    });
+}
+
+void ShellDBusClient::updateIsNotificationPopupDrawerOpen()
+{
+    auto reply = m_interface->isNotificationPopupDrawerOpen();
+    auto watcher = new QDBusPendingCallWatcher(reply, this);
+
+    QObject::connect(watcher, &QDBusPendingCallWatcher::finished, this, [this](auto watcher) {
+        QDBusPendingReply<bool> reply = *watcher;
+        m_isNotificationPopupDrawerOpen = reply.argumentAt<0>();
+        Q_EMIT isNotificationPopupDrawerOpenChanged();
+    });
+}
+
 void ShellDBusClient::updateIsTaskSwitcherVisible()
 {
     auto reply = m_interface->isTaskSwitcherVisible();
