@@ -18,6 +18,7 @@
 
 const QString CONFIG_FILE = QStringLiteral("plasmamobilerc");
 const QString GENERAL_CONFIG_GROUP = QStringLiteral("General");
+const QString LOCKSCREEN_CONFIG_GROUP = QStringLiteral("Lockscreen");
 
 MobileShellSettings::MobileShellSettings(QObject *parent)
     : QObject{parent}
@@ -32,6 +33,7 @@ MobileShellSettings::MobileShellSettings(QObject *parent)
             Q_EMIT animationsEnabledChanged();
             Q_EMIT dateInStatusBarChanged();
             Q_EMIT statusBarScaleFactorChanged();
+            Q_EMIT showBatteryPercentageChanged();
             Q_EMIT navigationPanelEnabledChanged();
             Q_EMIT alwaysShowKeyboardToggleOnNavigationPanelChanged();
             Q_EMIT keyboardButtonEnabledChanged();
@@ -39,8 +41,13 @@ MobileShellSettings::MobileShellSettings(QObject *parent)
             Q_EMIT actionDrawerTopLeftModeChanged();
             Q_EMIT actionDrawerTopRightModeChanged();
             Q_EMIT convergenceModeEnabledChanged();
+            Q_EMIT autoHidePanelsEnabledChanged();
             Q_EMIT allowLogoutChanged();
         }
+        if (group.name() == LOCKSCREEN_CONFIG_GROUP) {
+            Q_EMIT lockscreenLeftButtonActionChanged();
+            Q_EMIT lockscreenRightButtonActionChanged();
+        }
     });
 }
 
@@ -109,6 +116,19 @@ void MobileShellSettings::setStatusBarScaleFactor(float statusBarScaleFactor)
     m_config->sync();
 }
 
+bool MobileShellSettings::showBatteryPercentage() const
+{
+    auto group = KConfigGroup{m_config, GENERAL_CONFIG_GROUP};
+    return group.readEntry("showBatteryPercentage", true);
+}
+
+void MobileShellSettings::setShowBatteryPercentage(bool showBatteryPercentage)
+{
+    auto group = KConfigGroup{m_config, GENERAL_CONFIG_GROUP};
+    group.writeEntry("showBatteryPercentage", showBatteryPercentage, KConfigGroup::Notify);
+    m_config->sync();
+}
+
 bool MobileShellSettings::navigationPanelEnabled() const
 {
     auto group = KConfigGroup{m_config, GENERAL_CONFIG_GROUP};
@@ -182,6 +202,19 @@ void MobileShellSettings::setConvergenceModeEnabled(bool enabled)
     job->start();
 }
 
+bool MobileShellSettings::autoHidePanelsEnabled() const
+{
+    auto group = KConfigGroup{m_config, GENERAL_CONFIG_GROUP};
+    return group.readEntry("autoHidePanelsEnabled", false);
+}
+
+void MobileShellSettings::setAutoHidePanelsEnabled(bool enabled)
+{
+    auto group = KConfigGroup{m_config, GENERAL_CONFIG_GROUP};
+    group.writeEntry("autoHidePanelsEnabled", enabled, KConfigGroup::Notify);
+    m_config->sync();
+}
+
 void MobileShellSettings::updateNavigationBarsInPlasma(bool navigationPanelEnabled)
 {
     // Do not update panels when not in Plasma Mobile
@@ -224,3 +257,29 @@ bool MobileShellSettings::allowLogout() const
     auto group = KConfigGroup{m_config, GENERAL_CONFIG_GROUP};
     return group.readEntry("allowLogout", true);
 }
+
+MobileShellSettings::LockscreenButtonAction MobileShellSettings::lockscreenLeftButtonAction() const
+{
+    auto group = KConfigGroup{m_config, LOCKSCREEN_CONFIG_GROUP};
+    return (LockscreenButtonAction)group.readEntry("lockscreenLeftButtonAction", (int)LockscreenButtonAction::None);
+}
+
+void MobileShellSettings::setLockscreenLeftButtonAction(const LockscreenButtonAction action)
+{
+    auto group = KConfigGroup{m_config, LOCKSCREEN_CONFIG_GROUP};
+    group.writeEntry("lockscreenLeftButtonAction", (int)action, KConfigGroup::Notify);
+    m_config->sync();
+}
+
+MobileShellSettings::LockscreenButtonAction MobileShellSettings::lockscreenRightButtonAction() const
+{
+    auto group = KConfigGroup{m_config, LOCKSCREEN_CONFIG_GROUP};
+    return (LockscreenButtonAction)group.readEntry("lockscreenRightButtonAction", (int)LockscreenButtonAction::None);
+}
+
+void MobileShellSettings::setLockscreenRightButtonAction(const LockscreenButtonAction action)
+{
+    auto group = KConfigGroup{m_config, LOCKSCREEN_CONFIG_GROUP};
+    group.writeEntry("lockscreenRightButtonAction", (int)action, KConfigGroup::Notify);
+    m_config->sync();
+}
