@@ -10,6 +10,8 @@
 #include <QQuickItem>
 #include <QSet>
 
+#include <KService>
+
 #include "foliodelegate.h"
 #include "homescreen.h"
 
@@ -38,12 +40,20 @@ public:
 
     void load();
 
+Q_SIGNALS:
+    // Emitted when an application was detected to have been removed from the system
+    void applicationRemoved(QString storageId);
+
 public Q_SLOTS:
     void sycocaDbChanged();
 
 protected:
+    KService::List queryApplications();
+
     HomeScreen *m_homeScreen{nullptr};
-    QList<FolioDelegate *> m_delegates;
+
+    QList<std::shared_ptr<FolioDelegate>> m_delegates;
+    QTimer *m_reloadAppsTimer{nullptr};
 };
 
 class ApplicationListSearchModel : public QSortFilterProxyModel
