@@ -9,7 +9,9 @@
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <QClipboard>
+#include <QFile>
 #include <QGuiApplication>
+#include <QJsonArray>
 
 K_PLUGIN_CLASS_WITH_JSON(Info, "kcm_mobile_info.json")
 
@@ -21,12 +23,18 @@ Info::Info(QObject *parent, const KPluginMetaData &metaData)
 {
     setButtons({});
 
+    QFile vendorInfoFile;
+
+    vendorInfoFile.setFileName("/etc/vendorinfo.json");
+    vendorInfoFile.open(QIODevice::ReadOnly);
+    m_vendorInfo = QJsonDocument::fromJson(vendorInfoFile.readAll());
+
     qDebug() << "Info module loaded.";
 }
 
 void Info::copyInfoToClipboard() const
 {
-    const QString clipboardText = QStringLiteral(
+    QString clipboardText = QStringLiteral(
                                       "Operating System: %1\n"
                                       "KDE Plasma Version: %2\n"
                                       "KDE Frameworks Version: %3\n"
@@ -44,6 +52,17 @@ void Info::copyInfoToClipboard() const
                                            hardwareInfo()->processors(),
                                            hardwareInfo()->memory());
 
+    // add vendor information if available
+    if (!vendorInfoTitle().isEmpty()) {
+        for (const auto &li : vendorInfo()) {
+            const auto &m = li.toMap();
+            clipboardText.append(QString("%1: %2\n").arg(
+                m[QStringLiteral("Key")].toString(),
+                m[QStringLiteral("Value")].toString()
+            ));
+        }
+    }
+
     QGuiApplication::clipboard()->setText(clipboardText);
 }
 
@@ -62,4 +81,14 @@ HardwareInfo *Info::hardwareInfo() const
     return m_hardwareInfo;
 }
 
+QString Info::vendorInfoTitle() const
+{
+    return m_vendorInfo[QStringLiteral("Title")].toString();
+}
+
+QVariantList Info::vendorInfo() const
+{
+    return m_vendorInfo[QStringLiteral("Content")].toArray().toVariantList();
+}
+
 #include "info.moc"
