@@ -9,6 +9,8 @@
 #include "softwareinfo.h"
 #include <KQuickConfigModule>
 
+#include <QJsonDocument>
+
 #ifndef INFO_H
 #define INFO_H
 
@@ -19,10 +21,16 @@ class Info : public KQuickConfigModule
     Q_PROPERTY(DistroInfo *distroInfo READ distroInfo NOTIFY distroInfoChanged)
     Q_PROPERTY(SoftwareInfo *softwareInfo READ softwareInfo NOTIFY softwareInfoChanged)
     Q_PROPERTY(HardwareInfo *hardwareInfo READ hardwareInfo NOTIFY hardwareInfoChanged)
+    Q_PROPERTY(QVariantList vendorInfo READ vendorInfo CONSTANT)
+    Q_PROPERTY(QString vendorInfoTitle READ vendorInfoTitle CONSTANT)
+
     DistroInfo *distroInfo() const;
     SoftwareInfo *softwareInfo() const;
     HardwareInfo *hardwareInfo() const;
 
+    QVariantList vendorInfo() const;
+    QString vendorInfoTitle() const;
+
 public:
     Info(QObject *parent, const KPluginMetaData &metaData);
 
@@ -37,6 +45,7 @@ private:
     DistroInfo *m_distroInfo;
     SoftwareInfo *m_softwareInfo;
     HardwareInfo *m_hardwareInfo;
+    QJsonDocument m_vendorInfo;
 };
 
 #endif // INFO_H
